/// <reference types="node" />
import { AcceptedZipSources, BaseArchive } from './StreamArchive';
import { BasicArchiveInfo, PartialTweetGDPR, PartialTweet, AccountGDPR, ProfileGDPR, ClassicPayloadDetails, TwitterUserDetails, DMFile, GDPRMoment, DirectMessage, ArchiveSyntheticInfo, PartialFavorite, ExtendedInfoContainer, TwitterArchiveLoadOptions } from './TwitterTypes';
import DMArchive from './DMArchive';
import { EventEmitter } from 'events';
import TweetArchive from './TweetArchive';
import { FavoriteArchive } from './FavoriteArchive';
import UserData from './UserData';
import AdArchive from './AdArchive';
export declare type ArchiveReadState = "idle" | "reading" | "indexing" | "tweet_read" | "user_read" | "dm_read" | "extended_read" | "ready";
export declare type ArchiveDMImagesFormation = "none" | "inside" | "zipped";
/**
 * Represents a full Twitter Archive. Support GDPR and classic archive.
 *
 * You can check if the archive is a GDPR archive with property `.is_gdpr`.
 *
 * Available on both GDPR and old classic archives
 * -----
 * Tweets, that are available in `.tweets`.
 * Remember that, in searchs in particular, tweets are **NOT** sorted.
 *
 * Quick user information, like screen name, bio, location, ID and account
 * creation date is available through `.user[.summary]`.
 *
 *
 * Available on GDPR archives only
 * -----
 * Favorites, mutes, blocks, followings, followers, that are stored in
 * `.favorites`, `.mutes`, `.blocks`, `.followings` and `.followers`.
 *
 * Direct messages, parsed if archive is a GDPR archive, stored in `.messages`,
 * are returned and sorted from the most older to the more recent.
 *
 * Binary data of Direct Message images can be get through `.dmImagesOf(dm_id: string)` method.
 *
 * User detailled data (screen name history, email address) is in `.user` property.
 */
export declare class TwitterArchive {
    protected _ready: Promise<void>;
    protected archive: BaseArchive<any>;
    /** Current archive load state. */
    state: ArchiveReadState;
    /** Where events about archive read are emitted. */
    readonly events: EventEmitter;
    protected statuses: TweetArchive;
    protected dms: DMArchive;
    protected favs: FavoriteArchive;
    protected extended_info_container: ExtendedInfoContainer;
    protected _user: UserData;
    protected ad_archive: AdArchive;
    protected dm_img_archive: BaseArchive<any>;
    protected dm_img_group_archive: BaseArchive<any>;
    protected _is_gdpr: boolean;
    protected load_images_in_zip: boolean;
    protected _dm_images_type: ArchiveDMImagesFormation;
    protected _created_at: string;
    /**
     * Twitter Archive constructor.
     *
     * Don't forget to await the archive ready-ness with `.ready()` method !
     *
     * @param file Archive to load.
     *
     * If you want to build an archive instance **without** a file, you can pass `null` here.
     * You must then load parts of the archive with `.loadArchivePart()` or `.loadClassicArchivePart()` !
     *
     * @param options.load_images_in_zip
     * In Twitter GDPR archives v2, tweet and dm images are in ZIP archives inside the ZIP.
     * If `true`, TwitterArchive will extract its content in RAM to allow the usage of images.
     * If `false`, DMs images will be unavailable.
     * If `undefined`, Twitter will extract in RAM in browser mode, and leave the ZIP untouched in Node.js.
     *
     * If you want to save memory, set this parameter to `false`,
     * and before using `.dmImage()` methods, check if you need to load DM images ZIP
     * with `.requires_dm_image_load`.
     *
     * Then, if you need to, load the DM image ZIP present in the archive using `.loadArchivePart({ current_dm_images: true })`.
     *
     * @param options.build_ad_archive
     * `true` if ad data should be parsed and loaded.
     *
     * If you want to save time and memory at construct time, omit this parameter, it's set to `false` by default.
     *
     * Then, before first accessing `.ads`, load the archive data present in the archive
     * using `.loadArchivePart({ current_ad_archive: true })`.
     */
    constructor(file: AcceptedZipSources | Promise<AcceptedZipSources> | null, options?: TwitterArchiveLoadOptions);
    protected initGDPR(build_ad_archive: boolean): Promise<void>;
    protected initExtendedGDPR(): Promise<void>;
    protected initClassic(): Promise<void>;
    /** --------------- */
    /** DM IMAGES STUFF */
    /** --------------- */
    /**
     * Give the media url in direct message, obtain the Blob-bed image.
     * For use in Node.js, you must set `as_array_buffer` to `true` !
     */
    dmImageFromUrl(url: string, is_group?: boolean, as_array_buffer?: boolean): Promise<ArrayBuffer | Blob>;
    /**
     * Extract a direct message image from GDPR archive (exact filename required).
     * For use in Node.js, you must set `as_array_buffer` to `true` !
     */
    dmImage(name: string, is_group?: boolean, as_array_buffer?: boolean): Promise<Blob | ArrayBuffer>;
    /**
     * Return all the images of a direct message, as blob or array buffer.
     *
     * If the message does not exists or the DM archive is not loaded / available,
     * return an empty array.
     *
     * Otherwise, return a array of `Blob` / `ArrayBuffer`
     *
     * @param direct_message Direct Message id | Direct message
     * @param as_array_buffer Return an `ArrayBuffer` array, instead of a `Blob` array
     */
    dmImagesOf(direct_message: string | DirectMessage, as_array_buffer?: boolean): Promise<(Blob | ArrayBuffer)[]>;
    /** ----------------- */
    /** ARCHIVE ACCESSORS */
    /** ----------------- */
    /** `true` if ZIP file is still loaded inside this instance.
     * Can be freed (to save memory, f.e.) with `.releaseZip()`. */
    get is_zip_loaded(): boolean;
    /**
     * `true` if `.dmImage()` functions are accessible.
     *
     * `false` if you need to load a DM image ZIP in order to use `.dmImage()`.
     *
     * If you need to, use the `.loadArchivePart()` method:
     * - Loading the current DM image ZIP (if you've the constructor to not do so)
     * ```ts
     * await archive.loadArchivePart({ current_dm_images: true });
     * ```
     *
     * ---
     *
     * - Loading a custom DM ZIP (from external file)
     * ```ts
     * await archive.loadArchivePart({ dm_image_file: '<filepath.zip>' });
     * ```
     */
    get is_dm_images_available(): boolean;
    /** Archive creation date. Not accurate in GDPR archive (will be the current date). */
    get generation_date(): Date;
    /**
     * Archive quick information.
     *
     * - `.info.archive` : `{ created_at: string, tweets: number }`
     * - `.info.user`: See `TwitterUserDetails`
     */
    get info(): BasicArchiveInfo;
    /** `true` if archive is a GDPR archive. */
    get is_gdpr(): boolean;
    /**
     * Raw archive object. Can be used to get specific files.
     *
     * Returns `[twitter_archive, dm_image_archive, dm_group_image_archive]`.
     */
    get raw(): [BaseArchive<any>, BaseArchive<any> | undefined, BaseArchive<any> | undefined];
    /** Resolved when archive read is over. */
    ready(): Promise<void>;
    /** Access to the `DMArchive` object. Will be undefined if `.is_gdpr === false`. */
    get messages(): DMArchive;
    /** Access to the `TweetArchive` object. Contains all the tweets of this archive. */
    get tweets(): TweetArchive;
    /**
     * Access to the `FavoriteArchive` object. Contains all the favorited tweets of the archive.
     *
     * If `.is_gdpr === false`, this container will be empty.
     */
    get favorites(): FavoriteArchive;
    /**
     * Access to a set of followers IDs.
     *
     * If `.is_gdpr === false`, this container will be empty.
     */
    get followers(): Set<string>;
    /**
     * Access to a set of followings user IDs.
     *
     * If `.is_gdpr === false`, this container will be empty.
     */
    get followings(): Set<string>;
    /**
     * Access to a set of blocked user IDs.
     *
     * If `.is_gdpr === false`, this container will be empty.
     */
    get blocks(): Set<string>;
    /**
     * Access to a set of muted user IDs.
     *
     * If `.is_gdpr === false`, this container will be empty.
     */
    get mutes(): Set<string>;
    /**
     * Access to archive Twitter moments.
     *
     * If `.is_gdpr === false`, this array will be empty.
     */
    get moments(): GDPRMoment[];
    /**
     * Access to your subscribed and created lists, and the lists you were added into.
     *
     * If `.is_gdpr === false`, this container will be contain empty arrays.
     */
    get lists(): {
        created: string[];
        member_of: string[];
        subscribed: string[];
    };
    /**
     * All the archive owner's user data on Twitter.
     *
     * Contains data sended to Twitter about archive owner, like:
     * - **Screen name (@)**
     * - **Tweet name (TN)**
     * - **Account creation date**
     * - **Biography**
     * - **Phone number**
     * - **Personnalization** (inferred informations about user interests)
     * - **Email addresses**
     * - *...*
     *
     * If `.is_gdpr === false`, this is will contain only basic data (related to `.user.summary`).
     */
    get user(): UserData;
    /**
     * Informations about which ads archive owner seen or interacted with.
     *
     * `AdArchive` container does not contain any data if you
     * haven't used `{ build_ad_archive: true }` constructor parameter.
     */
    get ads(): AdArchive;
    /** -------------------- */
    /** SIDELOADING MANUALLY */
    /** -------------------- */
    /**
     * Load a part of a GDPR archive.
     *
     * Set current archive as GDPR archive.
     *
     * ---
     *
     * **Warning**: The DMs image parameters / current_ad_archive causes the read of new data.
     * Read is asynchronous, you **must** wait read end before trying to get images / ad data.
     *
     * ---
     *
     * If you use the `current_*` parameters, ensure that archive is still loaded (`.is_zip_loaded`).
     */
    loadArchivePart(parts?: {
        tweets?: PartialTweetGDPR[];
        account?: AccountGDPR;
        profile?: ProfileGDPR;
        dms?: DMFile[];
        dm_image_file?: AcceptedZipSources | Promise<AcceptedZipSources>;
        dm_image_group_file?: AcceptedZipSources | Promise<AcceptedZipSources>;
        current_dm_images?: boolean;
        current_ad_archive?: boolean;
        favorites?: PartialFavorite[];
        blocks?: string[];
        mutes?: string[];
        followers?: string[];
        followings?: string[];
        moments?: GDPRMoment[];
    }): Promise<void>;
    /**
     * Load a part of a classic archive.
     *
     * Set current archive as non-gdpr archive.
     */
    loadClassicArchivePart(parts?: {
        tweets?: PartialTweet[];
        payload?: ClassicPayloadDetails;
        user?: TwitterUserDetails;
    }): void;
    /**
     * Import a custom ZIP file as DM single-conversation images file.
     */
    protected importDmImageZip(file: AcceptedZipSources | Promise<AcceptedZipSources>, group?: boolean): Promise<void>;
    /**
     * Load/reload zip archives that contains DM images,
     * if `load_images_in_zip` parameter was set to false.
     *
     * You need to have the archive loaded to accomplish this action.
     *
     * Note that if any zip is found in the archive, this method will just do nothing.
     */
    protected loadCurrentDmImageZip(): Promise<void>;
    protected initUserCache(): void;
    /** --------------------------------------- */
    /** ARCHIVE FINGERPRINTING AND INFORMATIONS */
    /** --------------------------------------- */
    /**
     * Unload ZIP file inside this instance.
     *
     * Please note that if the ZIP files are still required for operations,
     * this method will do nothing if parameter `force` is `false`.
     *
     * **Warning: Before calling this method, check if `.is_dm_images_available` is `true` !**
     * If not, if you want DM images to be available, please do it with `.loadArchivePart({ current_dm_images: true })`.
     *
     * ```ts
     * if (!archive.is_dm_images_available) {
     *  await archive.loadArchivePart({ current_dm_images: true });
     * }
     * archive.releaseZip();
     * ```
     *
     * Returns `true` if ZIP has been unloaded.
     */
    releaseZip(force?: boolean): boolean;
    /**
     * Résumé of this archive.
     *
     * Contains the 'archive index' (without the tweets),
     * if the archive is GDPR, last tweet date,
     * tweet count and dm count.
     */
    get synthetic_info(): ArchiveSyntheticInfo;
    /**
     * `.synthetic_info`, but without hash. Used to... calculate hash.
     */
    protected get synthetic_info_without_hash(): ArchiveSyntheticInfo;
    /**
     * Create a pseudo-unique hash from a archive information (number of tweets, owner, last tweet date...),
     * in order to have a fingerprint of one archive.
     */
    static hash(from: ArchiveSyntheticInfo | TwitterArchive): string;
    /**
     * Pseudo-unique hash from the archive information (number of tweets, owner, last tweet date...),
     * in order to have a fingerprint of this archive.
     */
    get hash(): string;
    protected static autoDetectDmStoreType(archive: BaseArchive<any>): ArchiveDMImagesFormation;
    /**
     * @deprecated
     * For compatibility only. Use `.events.on()` instead.
     */
    addEventListener(event: string, listener: (...args: any[]) => void): void;
    /**
     * @deprecated
     * For compatibility only. Use `.events.off()` instead.
     */
    removeEventListener(event: string, listener: (...args: any[]) => void): void;
}
